/*
	alt-tasks : utility for observing ALT Linux tasks
	Copyright (C) 2020-2023 Alexey Appolonov

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

package ar

import (
	"bytes"
	"encoding/gob"
	)

//-----------------------------------------------------------------------------
// Get values of fields of an Archive obj

func (a *Archive) fields() []interface{} {
	return []interface{}{
		a.counter,
		a.tasks,
		a.packages,
		a.package_ids,
		a.time_overview,
		a.src_overview,
		}
	}

//-----------------------------------------------------------------------------
// Perform given action on all fields

func (a *Archive) forAll(f func(interface{}) error) error {

	for _, field := range a.fields() {
		if err := f(field); err != nil {
			return err
			}
		}

	return nil
	}

func (a *Archive) forAllP(f func(interface{}) error) error {

	err := f(&a.counter)
	if err == nil {
		err = f(&a.tasks)
		}
	if err == nil {
		err = f(&a.packages)
		}
	if err == nil {
		err = f(&a.package_ids)
		}
	if err == nil {
		err = f(&a.time_overview)
		}
	if err == nil {
		err = f(&a.src_overview)
		}

	return err
	}

//-----------------------------------------------------------------------------
// Encode to binary form

func (a *Archive) Encode() ([]byte, error) {

	b := new(bytes.Buffer)
	enc := gob.NewEncoder(b)

	if err := a.forAll(enc.Encode); err != nil {
		return nil, err
		}

	return b.Bytes(), nil
	}

//-----------------------------------------------------------------------------
// Decode from binary form

func (a *Archive) Decode(b []byte) error {

	dec := gob.NewDecoder(bytes.NewBuffer(b))
	if err := a.forAllP(dec.Decode); err != nil {
		return err
		}

	return nil
	}
