/*
	alt-tasks : utility for observing ALT Linux tasks
	Copyright (C) 2020-2023 Alexey Appolonov

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

package ar

import "fmt"

//-----------------------------------------------------------------------------
// Types that make up the Archive type

type TaskId    uint
type SubTaskId uint
type SrcId     uint
type Timestamp uint

// Alt Linux task
type Task map[SubTaskId]SubTask

// Sub task that make up each ALT Linux task
type SubTask struct {
	TS        Timestamp
	Src       SrcPackage
	BuiltFrom string
	HashSum   string
	}

// Src package with unique id in place of a name
type SrcPackage struct {
	// Using num ids to optimise a mem consumption and to increase a performance
	ID   SrcId
	Ver  string
	Rel  string
	Ver0 string
	Rel0 string
	}

// Get current or previous <ver>-<rel> of this package
func (src SrcPackage) VerRel () string {
	return fmt.Sprintf("%s-%s", src.Ver, src.Rel)
	}
func (src SrcPackage) Ver0Rel0 () string {
	return fmt.Sprintf("%s-%s", src.Ver0, src.Rel0)
	}

// Overview-object should help to find particular elements in map of tasks
// from a specific standpoint like by a timestamp of a task, for instance
type timeOverview map[Timestamp]map[TaskId]bool
type srcOverview  map[SrcId]map[TaskId]bool

// Variable of this type is used to update the "Ver0" and "Rel0" fields
// (previous version and release of a package) of a "SrcPackage"
// (Archive -> Task -> SubTask -> SrcPackage)
type PackagesUpdate struct {
	TaskId
	Entries []PackageUpdate
	}

// Previous version and release of a package
type PackageUpdate struct {
	SrcName string
	Ver0    string
	Rel0    string
	}
