/*
	alt-tasks : utility for observing ALT Linux tasks
	Copyright (C) 2020-2023 Alexey Appolonov

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

package cflag

import (
	"internal/hlp"

	"flag"
	"fmt"
	"time"
	)

//-----------------------------------------------------------------------------
// dateFlag corresponds to the "flag.Value" interface

type dateFlag struct { datetime time.Time }

func (f * dateFlag) Set(str string) error {
	if !f.datetime.IsZero() {
		return fmt.Errorf("Re-assign of a date flag")
		}
	datetime, err := hlp.ConvStrToTime(str)
	if err != nil {
		return err
		}
	f.datetime = datetime
	return nil
	}

func (f * dateFlag) String() string {
	return f.datetime.String()
	}

//-----------------------------------------------------------------------------
// Create a flag for a time.Time obj

func Date(name string, usage string) *time.Time {
	var f dateFlag
	flag.CommandLine.Var(&f, name, usage)
	return &f.datetime
	}
