/*
	alt-tasks : utility for observing ALT Linux tasks
	Copyright (C) 2020-2023 Alexey Appolonov

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

package strval

import (
	"fmt"
	"strconv"
	"strings"
	)

//-----------------------------------------------------------------------------
// Objects that can be assigned with a string

type Assignable interface {
	Assign(string) error
	}

//-----------------------------------------------------------------------------
// *Unsigned corresponds to the "assignable" interface

type Unsigned uint

func (u *Unsigned) Assign (s string) error {
	v, err := strconv.Atoi(s)
	if err != nil || v < 0 {
		if err == nil {
			err = fmt.Errorf("Can't convert %q to uint", s)
			}
		return err
		}
	*u = Unsigned(v)
	return nil
	}

//-----------------------------------------------------------------------------
// *PairDash and *PairColon correspond to the "assignable" interface

type Pair struct {
	First  string
	Second string
	}

type PairDash  Pair
type PairColon Pair

func (p *Pair) Split (s string, delim string) error {
	fields := strings.Split(s, delim)
	if len(fields) != 2 {
		return fmt.Errorf("Wrong format of ver-rel string")
		}
	p.First, p.Second = fields[0], fields[1]
	return nil
	}

func (p *PairDash) Assign (s string) error {
	return (*Pair)(p).Split(s, "-")
	}

func (p *PairColon) Assign (s string) error {
	return (*Pair)(p).Split(s, ":")
	}
